@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require XSLoader;
 XSLoader::load('Doubly', $VERSION);
@@ -15,11 +15,11 @@ __END__
 
 =head1 NAME
 
-Doubly - The great new Doubly!
+Doubly - Doubly linked lists
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
